==> eslint-config-pegasus-3.1.0.tgz: package/CHANGELOG.md <==
# CHANGELOG

All notable changes to this project are documented in this file.

## v3.1.0 (2021-11-10)

- Add rule no-unused-private-class-members ([4280173](https://github.com/sibiraj-s/eslint-config-pegasus/commit/4280173))
- Add rule no-unsafe-optional-chaining ([39c2022](https://github.com/sibiraj-s/eslint-config-pegasus/commit/39c2022))
- Add rule no-nonoctal-decimal-escape ([bb1c6a0](https://github.com/sibiraj-s/eslint-config-pegasus/commit/bb1c6a0))

## v3.0.1 (2021-10-28)

- disable rule class-methods-use-this ([e721787](https://github.com/sibiraj-s/eslint-config-pegasus/commit/e721787))
- update typescript-eslint to v5.2.0 ([c7e8098](https://github.com/sibiraj-s/eslint-config-pegasus/commit/c7e8098))

## v3.0.0 (2021-10-18)

- support eslint v8 ([7ac1c6a](https://github.com/sibiraj-s/eslint-config-pegasus/commit/7ac1c6a))

## v2.1.1 (2021-09-27)

- disable line-comment-position ([6291648](https://github.com/sibiraj-s/eslint-config-pegasus/commit/6291648))
- bump dependencies and devDependencies ([77e607b](https://github.com/sibiraj-s/eslint-config-pegasus/commit/77e607b))

## v2.1.0 (2021-06-21)

- add typescript rule `no-shadow` ([7b680f0](https://github.com/sibiraj-s/eslint-config-pegasus/commit/7b680f0))

## v2.0.3 (2021-05-24)

- bump dependencies and devDependencies ([c8709f8](https://github.com/sibiraj-s/eslint-config-pegasus/commit/c8709f8))
- disable lines-around-comment ([ea3d0ad](https://github.com/sibiraj-s/eslint-config-pegasus/commit/ea3d0ad))

## v2.0.2 (2021-04-16)

- bump dependencies and devDependencies ([098e033](https://github.com/sibiraj-s/eslint-config-pegasus/commit/098e033))
- ignore parens around multi-line jsx ([8dd7d07](https://github.com/sibiraj-s/eslint-config-pegasus/commit/8dd7d07))

## v2.0.1 (2020-12-14)

- bump dependencies and devDependencies ([5efc8a8](https://github.com/sibiraj-s/eslint-config-pegasus/commit/5efc8a8))
- update LICENSE ([ce899a6](https://github.com/sibiraj-s/eslint-config-pegasus/commit/ce899a6))

## v2.0.0 (2020-11-21)

- enforce `no-console` rule ([6ecf923](https://github.com/sibiraj-s/eslint-config-pegasus/commit/6ecf923))
- add typescript rules ([8e9a2ce](https://github.com/sibiraj-s/eslint-config-pegasus/commit/8e9a2ce))
- update to node.js v14 in ci ([1f28c53](https://github.com/sibiraj-s/eslint-config-pegasus/commit/1f28c53))
- setup @actions/cache ([103438d](https://github.com/sibiraj-s/eslint-config-pegasus/commit/103438d))
- update dependencies and devDependencies ([43f02b4](https://github.com/sibiraj-s/eslint-config-pegasus/commit/43f02b4))

## v1.3.10 (2020-10-05)

- update rule max-lines-per-function ([028e33d](https://github.com/sibiraj-s/eslint-config-pegasus/commit/028e33d))
- update rule no-extra-parens ([327e9f7](https://github.com/sibiraj-s/eslint-config-pegasus/commit/327e9f7))
- disable rule arrow-body-style ([b01c619](https://github.com/sibiraj-s/eslint-config-pegasus/commit/b01c619))

## v1.3.9 (2020-08-24)

- publish typescript rules ([e745340](https://github.com/sibiraj-s/eslint-config-pegasus/commit/e745340))

## v1.3.8 (2020-08-24)

- add rules for typescript ([f6a4510](https://github.com/sibiraj-s/eslint-config-pegasus/commit/f6a4510))

## v1.3.7 (2020-08-23)

- add rules for nodejs environment ([429bd6c](https://github.com/sibiraj-s/eslint-config-pegasus/commit/429bd6c))

## v1.3.6 (2020-08-17)

- update rule no-extra-parens ([6cbc30a](https://github.com/sibiraj-s/eslint-config-pegasus/commit/6cbc30a))
- disable rule no-inline-comments ([4c70b23](https://github.com/sibiraj-s/eslint-config-pegasus/commit/4c70b23))
- remove duplicate rules ([c0e3b29](https://github.com/sibiraj-s/eslint-config-pegasus/commit/c0e3b29))
- disable rule no-undefined ([2886278](https://github.com/sibiraj-s/eslint-config-pegasus/commit/2886278))

## v1.3.5 (2020-08-17)

- update rule complexity ([9895cba](https://github.com/sibiraj-s/eslint-config-pegasus/commit/9895cba))

## v1.3.4 (2020-08-17)

- update rule new-cap ([39f5832](https://github.com/sibiraj-s/eslint-config-pegasus/commit/39f5832))
- update rule newline-per-chained-call ([549251d](https://github.com/sibiraj-s/eslint-config-pegasus/commit/549251d))
- update rule max-statements ([547ba2b](https://github.com/sibiraj-s/eslint-config-pegasus/commit/547ba2b))

## v1.3.3 (2020-08-16)

- disable rule no-negated-condition ([424f9c4](https://github.com/sibiraj-s/eslint-config-pegasus/commit/424f9c4))

## v1.3.2 (2020-08-16)

- update rule max-statements ([004a1e9](https://github.com/sibiraj-s/eslint-config-pegasus/commit/004a1e9))
- update rule max-statements-per-line ([c31772a](https://github.com/sibiraj-s/eslint-config-pegasus/commit/c31772a))

## v1.3.1 (2020-08-16)

- update rule func-names ([bcb8172](https://github.com/sibiraj-s/eslint-config-pegasus/commit/bcb8172))

## v1.3.0 (2020-08-16)

- add style based rules ([558e896...38e40f3](https://github.com/sibiraj-s/eslint-config-pegasus/compare/558e896...38e40f3))
- add es6 rules ([5b9e29f...e2e76ea](https://github.com/sibiraj-s/eslint-config-pegasus/compare/5b9e29f...e2e76ea))
- add rules for best-practices ([8cd0718...fbf2e12](https://github.com/sibiraj-s/eslint-config-pegasus/compare/8cd0718...fbf2e12))
- add rules that relate to variable declarations ([2bced53...74ab5a1](https://github.com/sibiraj-s/eslint-config-pegasus/compare/2bced53...74ab5a1))
- add rules to avoid common errors ([9bdc30d...b8e5232](https://github.com/sibiraj-s/eslint-config-pegasus/compare/9bdc30d...b8e5232))

## v1.2.0 (2020-08-07)

**New Rules**

- array-element-newline ([3786bc3](https://github.com/sibiraj-s/eslint-config-pegasus/commit/3786bc3))
- array-bracket-newline ([7a69716](https://github.com/sibiraj-s/eslint-config-pegasus/commit/7a69716))
- array-bracket-spacing ([98ce96c](https://github.com/sibiraj-s/eslint-config-pegasus/commit/98ce96c))
- block-spacing ([c3f7a25](https://github.com/sibiraj-s/eslint-config-pegasus/commit/c3f7a25))
- brace-style ([907ff67](https://github.com/sibiraj-s/eslint-config-pegasus/commit/907ff67))
- camelcase ([0b56a85](https://github.com/sibiraj-s/eslint-config-pegasus/commit/0b56a85))
- eol-last ([b76bc61](https://github.com/sibiraj-s/eslint-config-pegasus/commit/b76bc61))
- function-call-argument-newline ([44e091f](https://github.com/sibiraj-s/eslint-config-pegasus/commit/44e091f))
- func-call-spacing ([50e5a12](https://github.com/sibiraj-s/eslint-config-pegasus/commit/50e5a12))
- indent ([ea6d9c7](https://github.com/sibiraj-s/eslint-config-pegasus/commit/ea6d9c7))
- no-trailing-spaces ([10b1181](https://github.com/sibiraj-s/eslint-config-pegasus/commit/10b1181))
- no-unneeded-ternary ([81f8332](https://github.com/sibiraj-s/eslint-config-pegasus/commit/81f8332))
- no-whitespace-before-property ([a3d551b](https://github.com/sibiraj-s/eslint-config-pegasus/commit/a3d551b))
- object-curly-spacing ([de5fb5e](https://github.com/sibiraj-s/eslint-config-pegasus/commit/de5fb5e))
- space-before-blocks ([80e4adc](https://github.com/sibiraj-s/eslint-config-pegasus/commit/80e4adc))
- space-before-function-paren ([4a2d374](https://github.com/sibiraj-s/eslint-config-pegasus/commit/4a2d374))
- space-in-parens ([4420036](https://github.com/sibiraj-s/eslint-config-pegasus/commit/4420036))
- space-infix-ops ([2fbde7b](https://github.com/sibiraj-s/eslint-config-pegasus/commit/2fbde7b))
- space-unary-ops ([03ac1d2](https://github.com/sibiraj-s/eslint-config-pegasus/commit/03ac1d2))
- spaced-comment ([380faa9](https://github.com/sibiraj-s/eslint-config-pegasus/commit/380faa9))
- switch-colon-spacing ([9b9837b](https://github.com/sibiraj-s/eslint-config-pegasus/commit/9b9837b))
- generator-star-spacing ([125b49a](https://github.com/sibiraj-s/eslint-config-pegasus/commit/125b49a))
- comma-spacing ([29d4652](https://github.com/sibiraj-s/eslint-config-pegasus/commit/29d4652))

## v1.1.0 (2020-07-23)

- add `no-dupe-keys` rule ([a94bd94](https://github.com/sibiraj-s/eslint-config-pegasus/commit/a94bd94))

## v1.0.0 (2020-07-04)

- eslint shareable config ([9b576a3](https://github.com/sibiraj-s/eslint-config-pegasus/commit/9b576a3))

==> eslint-config-pegasus-3.1.1.tgz: package/CHANGELOG.md <==
# CHANGELOG

All notable changes to this project are documented in this file.

## v3.1.1 (2021-12-15)

- update rule object-curly-newline ([e84cb84](https://github.com/sibiraj-s/eslint-config-pegasus/commit/e84cb84))
- bump dependencies and devDependencies ([6e30266](https://github.com/sibiraj-s/eslint-config-pegasus/commit/6e30266))

## v3.1.0 (2021-11-10)

- add rule no-unused-private-class-members ([4280173](https://github.com/sibiraj-s/eslint-config-pegasus/commit/4280173))
- add rule no-unsafe-optional-chaining ([39c2022](https://github.com/sibiraj-s/eslint-config-pegasus/commit/39c2022))
- add rule no-nonoctal-decimal-escape ([bb1c6a0](https://github.com/sibiraj-s/eslint-config-pegasus/commit/bb1c6a0))

## v3.0.1 (2021-10-28)

- disable rule class-methods-use-this ([e721787](https://github.com/sibiraj-s/eslint-config-pegasus/commit/e721787))
- update typescript-eslint to v5.2.0 ([c7e8098](https://github.com/sibiraj-s/eslint-config-pegasus/commit/c7e8098))

## v3.0.0 (2021-10-18)

- support eslint v8 ([7ac1c6a](https://github.com/sibiraj-s/eslint-config-pegasus/commit/7ac1c6a))

## v2.1.1 (2021-09-27)

- disable line-comment-position ([6291648](https://github.com/sibiraj-s/eslint-config-pegasus/commit/6291648))
- bump dependencies and devDependencies ([77e607b](https://github.com/sibiraj-s/eslint-config-pegasus/commit/77e607b))

## v2.1.0 (2021-06-21)

- add typescript rule `no-shadow` ([7b680f0](https://github.com/sibiraj-s/eslint-config-pegasus/commit/7b680f0))

## v2.0.3 (2021-05-24)

- bump dependencies and devDependencies ([c8709f8](https://github.com/sibiraj-s/eslint-config-pegasus/commit/c8709f8))
- disable lines-around-comment ([ea3d0ad](https://github.com/sibiraj-s/eslint-config-pegasus/commit/ea3d0ad))

## v2.0.2 (2021-04-16)

- bump dependencies and devDependencies ([098e033](https://github.com/sibiraj-s/eslint-config-pegasus/commit/098e033))
- ignore parens around multi-line jsx ([8dd7d07](https://github.com/sibiraj-s/eslint-config-pegasus/commit/8dd7d07))

## v2.0.1 (2020-12-14)

- bump dependencies and devDependencies ([5efc8a8](https://github.com/sibiraj-s/eslint-config-pegasus/commit/5efc8a8))
- update LICENSE ([ce899a6](https://github.com/sibiraj-s/eslint-config-pegasus/commit/ce899a6))

## v2.0.0 (2020-11-21)

- enforce `no-console` rule ([6ecf923](https://github.com/sibiraj-s/eslint-config-pegasus/commit/6ecf923))
- add typescript rules ([8e9a2ce](https://github.com/sibiraj-s/eslint-config-pegasus/commit/8e9a2ce))
- update to node.js v14 in ci ([1f28c53](https://github.com/sibiraj-s/eslint-config-pegasus/commit/1f28c53))
- setup @actions/cache ([103438d](https://github.com/sibiraj-s/eslint-config-pegasus/commit/103438d))
- update dependencies and devDependencies ([43f02b4](https://github.com/sibiraj-s/eslint-config-pegasus/commit/43f02b4))

## v1.3.10 (2020-10-05)

- update rule max-lines-per-function ([028e33d](https://github.com/sibiraj-s/eslint-config-pegasus/commit/028e33d))
- update rule no-extra-parens ([327e9f7](https://github.com/sibiraj-s/eslint-config-pegasus/commit/327e9f7))
- disable rule arrow-body-style ([b01c619](https://github.com/sibiraj-s/eslint-config-pegasus/commit/b01c619))

## v1.3.9 (2020-08-24)

- publish typescript rules ([e745340](https://github.com/sibiraj-s/eslint-config-pegasus/commit/e745340))

## v1.3.8 (2020-08-24)

- add rules for typescript ([f6a4510](https://github.com/sibiraj-s/eslint-config-pegasus/commit/f6a4510))

## v1.3.7 (2020-08-23)

- add rules for nodejs environment ([429bd6c](https://github.com/sibiraj-s/eslint-config-pegasus/commit/429bd6c))

## v1.3.6 (2020-08-17)

- update rule no-extra-parens ([6cbc30a](https://github.com/sibiraj-s/eslint-config-pegasus/commit/6cbc30a))
- disable rule no-inline-comments ([4c70b23](https://github.com/sibiraj-s/eslint-config-pegasus/commit/4c70b23))
- remove duplicate rules ([c0e3b29](https://github.com/sibiraj-s/eslint-config-pegasus/commit/c0e3b29))
- disable rule no-undefined ([2886278](https://github.com/sibiraj-s/eslint-config-pegasus/commit/2886278))

## v1.3.5 (2020-08-17)

- update rule complexity ([9895cba](https://github.com/sibiraj-s/eslint-config-pegasus/commit/9895cba))

## v1.3.4 (2020-08-17)

- update rule new-cap ([39f5832](https://github.com/sibiraj-s/eslint-config-pegasus/commit/39f5832))
- update rule newline-per-chained-call ([549251d](https://github.com/sibiraj-s/eslint-config-pegasus/commit/549251d))
- update rule max-statements ([547ba2b](https://github.com/sibiraj-s/eslint-config-pegasus/commit/547ba2b))

## v1.3.3 (2020-08-16)

- disable rule no-negated-condition ([424f9c4](https://github.com/sibiraj-s/eslint-config-pegasus/commit/424f9c4))

## v1.3.2 (2020-08-16)

- update rule max-statements ([004a1e9](https://github.com/sibiraj-s/eslint-config-pegasus/commit/004a1e9))
- update rule max-statements-per-line ([c31772a](https://github.com/sibiraj-s/eslint-config-pegasus/commit/c31772a))

## v1.3.1 (2020-08-16)

- update rule func-names ([bcb8172](https://github.com/sibiraj-s/eslint-config-pegasus/commit/bcb8172))

## v1.3.0 (2020-08-16)

- add style based rules ([558e896...38e40f3](https://github.com/sibiraj-s/eslint-config-pegasus/compare/558e896...38e40f3))
- add es6 rules ([5b9e29f...e2e76ea](https://github.com/sibiraj-s/eslint-config-pegasus/compare/5b9e29f...e2e76ea))
- add rules for best-practices ([8cd0718...fbf2e12](https://github.com/sibiraj-s/eslint-config-pegasus/compare/8cd0718...fbf2e12))
- add rules that relate to variable declarations ([2bced53...74ab5a1](https://github.com/sibiraj-s/eslint-config-pegasus/compare/2bced53...74ab5a1))
- add rules to avoid common errors ([9bdc30d...b8e5232](https://github.com/sibiraj-s/eslint-config-pegasus/compare/9bdc30d...b8e5232))

## v1.2.0 (2020-08-07)

**New Rules**

- array-element-newline ([3786bc3](https://github.com/sibiraj-s/eslint-config-pegasus/commit/3786bc3))
- array-bracket-newline ([7a69716](https://github.com/sibiraj-s/eslint-config-pegasus/commit/7a69716))
- array-bracket-spacing ([98ce96c](https://github.com/sibiraj-s/eslint-config-pegasus/commit/98ce96c))
- block-spacing ([c3f7a25](https://github.com/sibiraj-s/eslint-config-pegasus/commit/c3f7a25))
- brace-style ([907ff67](https://github.com/sibiraj-s/eslint-config-pegasus/commit/907ff67))
- camelcase ([0b56a85](https://github.com/sibiraj-s/eslint-config-pegasus/commit/0b56a85))
- eol-last ([b76bc61](https://github.com/sibiraj-s/eslint-config-pegasus/commit/b76bc61))
- function-call-argument-newline ([44e091f](https://github.com/sibiraj-s/eslint-config-pegasus/commit/44e091f))
- func-call-spacing ([50e5a12](https://github.com/sibiraj-s/eslint-config-pegasus/commit/50e5a12))
- indent ([ea6d9c7](https://github.com/sibiraj-s/eslint-config-pegasus/commit/ea6d9c7))
- no-trailing-spaces ([10b1181](https://github.com/sibiraj-s/eslint-config-pegasus/commit/10b1181))
- no-unneeded-ternary ([81f8332](https://github.com/sibiraj-s/eslint-config-pegasus/commit/81f8332))
- no-whitespace-before-property ([a3d551b](https://github.com/sibiraj-s/eslint-config-pegasus/commit/a3d551b))
- object-curly-spacing ([de5fb5e](https://github.com/sibiraj-s/eslint-config-pegasus/commit/de5fb5e))
- space-before-blocks ([80e4adc](https://github.com/sibiraj-s/eslint-config-pegasus/commit/80e4adc))
- space-before-function-paren ([4a2d374](https://github.com/sibiraj-s/eslint-config-pegasus/commit/4a2d374))
- space-in-parens ([4420036](https://github.com/sibiraj-s/eslint-config-pegasus/commit/4420036))
- space-infix-ops ([2fbde7b](https://github.com/sibiraj-s/eslint-config-pegasus/commit/2fbde7b))
- space-unary-ops ([03ac1d2](https://github.com/sibiraj-s/eslint-config-pegasus/commit/03ac1d2))
- spaced-comment ([380faa9](https://github.com/sibiraj-s/eslint-config-pegasus/commit/380faa9))
- switch-colon-spacing ([9b9837b](https://github.com/sibiraj-s/eslint-config-pegasus/commit/9b9837b))
- generator-star-spacing ([125b49a](https://github.com/sibiraj-s/eslint-config-pegasus/commit/125b49a))
- comma-spacing ([29d4652](https://github.com/sibiraj-s/eslint-config-pegasus/commit/29d4652))

## v1.1.0 (2020-07-23)

- add `no-dupe-keys` rule ([a94bd94](https://github.com/sibiraj-s/eslint-config-pegasus/commit/a94bd94))

## v1.0.0 (2020-07-04)

- eslint shareable config ([9b576a3](https://github.com/sibiraj-s/eslint-config-pegasus/commit/9b576a3))
